pub enum ActorRestartStrategy {
Immediate,
LinearBackOff {
timeout: Duration,
},
ExponentialBackOff {
timeout: Duration,
multiplier: f64,
},
}Expand description
The strategy for restating an actor as far as it returned an failure.
The default strategy is Immediate.
Variants
Immediate
Restart an actor as soon as possible, since the moment the actor finished with a failure.
LinearBackOff
Restart an actor after with the timeout. Each next restart is increasing on the given duration.
ExponentialBackOff
Restart an actor after with the timeout. Each next timeout is increasing exponentially. When passed a multiplier that equals to 1, the strategy works as the linear back off strategy. Passing the multiplier that equals to 0 leads to constant restart delays which is equal to the given timeout.
Implementations